@@ -13,21 +13,31 @@ import pandas as pd
 
 
 def connet_db(conn_str):
-    engine = create_engine(conn_str, encoding='utf-8')
+    engine = create_engine(conn_str)
     db_session = sessionmaker(bind=engine)
     session = db_session()
     return session
 
 
-def only_query(conn, sql):
+def only_query(conn, sql, params=None):
+    """
+    使用 records 执行带参数的 SQL 查询
+    
+    :param conn: 数据库连接字符串或 URI
+    :param sql: 带命名参数的 SQL 字符串（如 :phone）
+    :param params: 参数字典，如 {"phone": "xxx", "project_id": 123}
+    :return: 查询结果列表（每行是一个 dict）
+    """
     db = records.Database(conn)
-    rows = db.query(sql)  # or db.query_file('sqls/active-users.sql')
-    return rows
+    raw_sql = sql.text if hasattr(sql, 'text') else sql
+    rows = db.query(raw_sql, **(params or {}))  # 支持参数化查询
+    return rows  # 返回字典格式数据
 
 
-def exec_sql(conn, sql):
+def exec_sql(conn, sql, params=None):
     session = connet_db(conn)
-    tmp_list = session.execute(sql)
+    raw_sql = sql.text if hasattr(sql, 'text') else sql
+    tmp_list = session.execute(raw_sql)
     session.commit()
     return tmp_list
 
@@ -44,3 +54,10 @@ def write_csv_insert_db(conn, table_name, fieldnames, data, csv_file=None):
         engine = create_engine(conn)
         rows = pd.read_csv(csv_file)
         rows.to_sql(table_name, con=engine, if_exists='append',index=False)
+        
+        
+if __name__ == '__main__':
+    CONN = f'mysql+pymysql://root:abc123@11.11.11.11:3306/demo'
+    sql = 'select * from ai_workcard_audio limit 10'
+    rows = only_query(CONN, sql)
+    print(rows)
